#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_tunnels_ext(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def get_tunnel_info_input_page_cursor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        page_cursor = ET.SubElement(input, "page-cursor")
        page_cursor.text = kwargs.pop('page_cursor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_id_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_id = ET.SubElement(filter_type, "filter-by-id")
        id = ET.SubElement(filter_by_id, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_mode_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_mode = ET.SubElement(filter_type, "filter-by-mode")
        mode = ET.SubElement(filter_by_mode, "mode")
        mode.text = kwargs.pop('mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_gateway_gw_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_gateway = ET.SubElement(filter_type, "filter-by-gateway")
        gw_name = ET.SubElement(filter_by_gateway, "gw-name")
        gw_name.text = kwargs.pop('gw_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_sip_src_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_sip = ET.SubElement(filter_type, "filter-by-sip")
        src_ip = ET.SubElement(filter_by_sip, "src-ip")
        src_ip.text = kwargs.pop('src_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_dip_dest_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_dip = ET.SubElement(filter_type, "filter-by-dip")
        dest_ip = ET.SubElement(filter_by_dip, "dest-ip")
        dest_ip.text = kwargs.pop('dest_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_cfg_src_config_src(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_cfg_src = ET.SubElement(filter_type, "filter-by-cfg-src")
        config_src = ET.SubElement(filter_by_cfg_src, "config-src")
        config_src.text = kwargs.pop('config_src')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_site_site_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_site = ET.SubElement(filter_type, "filter-by-site")
        site_name = ET.SubElement(filter_by_site, "site-name")
        site_name.text = kwargs.pop('site_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_adm_state_admin_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_adm_state = ET.SubElement(filter_type, "filter-by-adm-state")
        admin_state = ET.SubElement(filter_by_adm_state, "admin-state")
        admin_state.text = kwargs.pop('admin_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_opr_state_oper_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_opr_state = ET.SubElement(filter_type, "filter-by-opr-state")
        oper_state = ET.SubElement(filter_by_opr_state, "oper-state")
        oper_state.text = kwargs.pop('oper_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_bfd_state_bfd_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_bfd_state = ET.SubElement(filter_type, "filter-by-bfd-state")
        bfd_state = ET.SubElement(filter_by_bfd_state, "bfd-state")
        bfd_state.text = kwargs.pop('bfd_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        id = ET.SubElement(tunnel, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        mode = ET.SubElement(tunnel, "mode")
        mode.text = kwargs.pop('mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_src_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        src_ip = ET.SubElement(tunnel, "src-ip")
        src_ip.text = kwargs.pop('src_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_dest_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        dest_ip = ET.SubElement(tunnel, "dest-ip")
        dest_ip.text = kwargs.pop('dest_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_vrf(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        vrf = ET.SubElement(tunnel, "vrf")
        vrf.text = kwargs.pop('vrf')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_config_src(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        config_src = ET.SubElement(tunnel, "config-src")
        config_src.text = kwargs.pop('config_src')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_admin_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        admin_state = ET.SubElement(tunnel, "admin-state")
        admin_state.text = kwargs.pop('admin_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_oper_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        oper_state = ET.SubElement(tunnel, "oper-state")
        oper_state.text = kwargs.pop('oper_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_bfd_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        bfd_state = ET.SubElement(tunnel, "bfd-state")
        bfd_state.text = kwargs.pop('bfd_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_has_conflicts(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        has_conflicts = ET.SubElement(tunnel, "has-conflicts")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_next_page_cursor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        next_page_cursor = ET.SubElement(output, "next-page-cursor")
        next_page_cursor.text = kwargs.pop('next_page_cursor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_input_page_cursor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        input = ET.SubElement(get_tunnel_statistics, "input")
        page_cursor = ET.SubElement(input, "page-cursor")
        page_cursor.text = kwargs.pop('page_cursor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_input_filter_type_filter_by_id_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        input = ET.SubElement(get_tunnel_statistics, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_id = ET.SubElement(filter_type, "filter-by-id")
        id = ET.SubElement(filter_by_id, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_input_filter_type_filter_by_mode_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        input = ET.SubElement(get_tunnel_statistics, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_mode = ET.SubElement(filter_type, "filter-by-mode")
        mode = ET.SubElement(filter_by_mode, "mode")
        mode.text = kwargs.pop('mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_input_filter_type_filter_by_gateway_gw_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        input = ET.SubElement(get_tunnel_statistics, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_gateway = ET.SubElement(filter_type, "filter-by-gateway")
        gw_name = ET.SubElement(filter_by_gateway, "gw-name")
        gw_name.text = kwargs.pop('gw_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        id = ET.SubElement(tunnel_stat, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_tx_frames(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        tx_frames = ET.SubElement(tunnel_stat, "tx-frames")
        tx_frames.text = kwargs.pop('tx_frames')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_tx_bytes(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        tx_bytes = ET.SubElement(tunnel_stat, "tx-bytes")
        tx_bytes.text = kwargs.pop('tx_bytes')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_rx_frames(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        rx_frames = ET.SubElement(tunnel_stat, "rx-frames")
        rx_frames.text = kwargs.pop('rx_frames')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_rx_bytes(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        rx_bytes = ET.SubElement(tunnel_stat, "rx-bytes")
        rx_bytes.text = kwargs.pop('rx_bytes')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_next_page_cursor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        next_page_cursor = ET.SubElement(output, "next-page-cursor")
        next_page_cursor.text = kwargs.pop('next_page_cursor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_page_cursor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        page_cursor = ET.SubElement(input, "page-cursor")
        page_cursor.text = kwargs.pop('page_cursor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_id_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_id = ET.SubElement(filter_type, "filter-by-id")
        id = ET.SubElement(filter_by_id, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_mode_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_mode = ET.SubElement(filter_type, "filter-by-mode")
        mode = ET.SubElement(filter_by_mode, "mode")
        mode.text = kwargs.pop('mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_gateway_gw_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_gateway = ET.SubElement(filter_type, "filter-by-gateway")
        gw_name = ET.SubElement(filter_by_gateway, "gw-name")
        gw_name.text = kwargs.pop('gw_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_sip_src_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_sip = ET.SubElement(filter_type, "filter-by-sip")
        src_ip = ET.SubElement(filter_by_sip, "src-ip")
        src_ip.text = kwargs.pop('src_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_dip_dest_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_dip = ET.SubElement(filter_type, "filter-by-dip")
        dest_ip = ET.SubElement(filter_by_dip, "dest-ip")
        dest_ip.text = kwargs.pop('dest_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_cfg_src_config_src(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_cfg_src = ET.SubElement(filter_type, "filter-by-cfg-src")
        config_src = ET.SubElement(filter_by_cfg_src, "config-src")
        config_src.text = kwargs.pop('config_src')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_site_site_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_site = ET.SubElement(filter_type, "filter-by-site")
        site_name = ET.SubElement(filter_by_site, "site-name")
        site_name.text = kwargs.pop('site_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_adm_state_admin_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_adm_state = ET.SubElement(filter_type, "filter-by-adm-state")
        admin_state = ET.SubElement(filter_by_adm_state, "admin-state")
        admin_state.text = kwargs.pop('admin_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_opr_state_oper_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_opr_state = ET.SubElement(filter_type, "filter-by-opr-state")
        oper_state = ET.SubElement(filter_by_opr_state, "oper-state")
        oper_state.text = kwargs.pop('oper_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_input_filter_type_filter_by_bfd_state_bfd_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        input = ET.SubElement(get_tunnel_info, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_bfd_state = ET.SubElement(filter_type, "filter-by-bfd-state")
        bfd_state = ET.SubElement(filter_by_bfd_state, "bfd-state")
        bfd_state.text = kwargs.pop('bfd_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        id = ET.SubElement(tunnel, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        mode = ET.SubElement(tunnel, "mode")
        mode.text = kwargs.pop('mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_src_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        src_ip = ET.SubElement(tunnel, "src-ip")
        src_ip.text = kwargs.pop('src_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_dest_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        dest_ip = ET.SubElement(tunnel, "dest-ip")
        dest_ip.text = kwargs.pop('dest_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_vrf(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        vrf = ET.SubElement(tunnel, "vrf")
        vrf.text = kwargs.pop('vrf')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_config_src(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        config_src = ET.SubElement(tunnel, "config-src")
        config_src.text = kwargs.pop('config_src')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_admin_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        admin_state = ET.SubElement(tunnel, "admin-state")
        admin_state.text = kwargs.pop('admin_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_oper_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        oper_state = ET.SubElement(tunnel, "oper-state")
        oper_state.text = kwargs.pop('oper_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_bfd_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        bfd_state = ET.SubElement(tunnel, "bfd-state")
        bfd_state.text = kwargs.pop('bfd_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_tunnel_has_conflicts(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        tunnel = ET.SubElement(output, "tunnel")
        has_conflicts = ET.SubElement(tunnel, "has-conflicts")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_info_output_next_page_cursor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_info = ET.Element("get_tunnel_info")
        config = get_tunnel_info
        output = ET.SubElement(get_tunnel_info, "output")
        next_page_cursor = ET.SubElement(output, "next-page-cursor")
        next_page_cursor.text = kwargs.pop('next_page_cursor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_input_page_cursor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        input = ET.SubElement(get_tunnel_statistics, "input")
        page_cursor = ET.SubElement(input, "page-cursor")
        page_cursor.text = kwargs.pop('page_cursor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_input_filter_type_filter_by_id_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        input = ET.SubElement(get_tunnel_statistics, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_id = ET.SubElement(filter_type, "filter-by-id")
        id = ET.SubElement(filter_by_id, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_input_filter_type_filter_by_mode_mode(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        input = ET.SubElement(get_tunnel_statistics, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_mode = ET.SubElement(filter_type, "filter-by-mode")
        mode = ET.SubElement(filter_by_mode, "mode")
        mode.text = kwargs.pop('mode')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_input_filter_type_filter_by_gateway_gw_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        input = ET.SubElement(get_tunnel_statistics, "input")
        filter_type = ET.SubElement(input, "filter-type")
        filter_by_gateway = ET.SubElement(filter_type, "filter-by-gateway")
        gw_name = ET.SubElement(filter_by_gateway, "gw-name")
        gw_name.text = kwargs.pop('gw_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        id = ET.SubElement(tunnel_stat, "id")
        id.text = kwargs.pop('id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_tx_frames(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        tx_frames = ET.SubElement(tunnel_stat, "tx-frames")
        tx_frames.text = kwargs.pop('tx_frames')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_tx_bytes(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        tx_bytes = ET.SubElement(tunnel_stat, "tx-bytes")
        tx_bytes.text = kwargs.pop('tx_bytes')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_rx_frames(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        rx_frames = ET.SubElement(tunnel_stat, "rx-frames")
        rx_frames.text = kwargs.pop('rx_frames')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_tunnel_stat_rx_bytes(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        tunnel_stat = ET.SubElement(output, "tunnel-stat")
        rx_bytes = ET.SubElement(tunnel_stat, "rx-bytes")
        rx_bytes.text = kwargs.pop('rx_bytes')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_tunnel_statistics_output_next_page_cursor(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_tunnel_statistics = ET.Element("get_tunnel_statistics")
        config = get_tunnel_statistics
        output = ET.SubElement(get_tunnel_statistics, "output")
        next_page_cursor = ET.SubElement(output, "next-page-cursor")
        next_page_cursor.text = kwargs.pop('next_page_cursor')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from pynos.versions.ver_7.ver_7_0_0.yang.brocade_rbridge import brocade_rbridge
import pynos.utilities


class Services(object):
    """
    The Services class holds all relevent methods and attributes for enabling
    and disabling NOS services, such as VRRP.

    Attributes:
        None
    """
    def __init__(self, callback):
        """
        Services object init.

        Args:
            callback: Callback function that will be called for each action.

        Returns:
            Services Object

        Raises:
            None
        """
        self._callback = callback
        self._rbridge = brocade_rbridge(callback=pynos.utilities.return_xml)

    def vrrp(self, **kwargs):
        """Enable or Disable VRRP.

        Args:
            ip_version (str): The IP version ('4' or '6') for which VRRP should
                be enabled/disabled.  Default: `4`.
            enabled (bool): If VRRP should be enabled or disabled.  Default:
                ``True``.
            rbridge_id (str): The rbridge ID of the device on which VRRP will
                be enabled/disabled.  Default: `1`.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            None

        Examples:
            >>> import pynos.device
            >>> switches = ['10.24.39.211', '10.24.39.203']
            >>> auth = ('admin', 'password')
            >>> for switch in switches:
            ...     conn = (switch, '22')
            ...     with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...         output = dev.bgp.local_asn(rbridge_id='225')
            ...         output = dev.bgp.local_asn(rbridge_id='225',
            ...         enabled=False)
            ...         output = dev.bgp.local_asn(rbridge_id='225',
            ...         ip_version='6')
            ...         output = dev.bgp.local_asn(rbridge_id='225',
            ...         enabled=False, ip_version='6')
            ...         dev.services.vrrp() # doctest: +IGNORE_EXCEPTION_DETAIL
            Traceback (most recent call last):
            KeyError
        """
        ip_version = kwargs.pop('ip_version', '4')
        enabled = kwargs.pop('enabled', True)
        rbridge_id = kwargs.pop('rbridge_id', '1')
        callback = kwargs.pop('callback', self._callback)
        vrrp_args = dict(rbridge_id=rbridge_id)
        vrrp_method = 'rbridge_id_protocol_hide_vrrp_holder_vrrp'
        if ip_version == '6':
            vrrp_method = 'rbridge_id_ipv6_proto_vrrpv3_vrrp'
        vrrp = getattr(self._rbridge, vrrp_method)
        config = vrrp(**vrrp_args)
        if not enabled:
            config.find('.//*vrrp').set('operation', 'delete')
        return callback(config)
